package cz.muni.fi.pb162.graphics;

import java.util.*;
import java.io.*;

public class Polygon extends AbstractGrObject
{
    private SortedMap<String,Point> points;
 
    public Polygon(Color color) {
        super(color);
        this.points = new TreeMap<String,Point>();
    }
    
    public void addPoint(String name, Point point) {
        if (point == null) throw new IllegalArgumentException("point");
        if (name == null) throw new IllegalArgumentException("name");
        points.put(name, point);
    }
    
    public String toString() {
        String ret = "";
        for (String key: points.keySet()) {
            Point p = points.get(key);
            ret += key + ":" + p.getX() + "," + p.getY() + "\n";
        }
        return ret;
    }
    
    public double getPerimeter() {
        double ret = 0;
        
        Point p1 = null;
        for (Point p2: points.values()) {
            if (p1 != null) ret += getLineLength(p1, p2);
            p1 = p2;
        }
        ret += getLineLength(p1, points.get(points.firstKey()));
        
        return ret;
    }
    
    /**
     * @param p1 first point of the line segment
     * @param p2 second point of the line segment
     * @return length of the line segment, -1.0 on error
     */
    protected static double getLineLength(Point p1, Point p2) { 
        //if (p1 == null || p2 == null) {
        //    return -1.0;
        //}
        
        int dx = p1.getX() - p2.getX();
        int dy = p1.getY() - p2.getY();
        return Math.sqrt(dx * dx + dy * dy);
    }
    
    public SortedSet<Point> getPoints() {
        SortedSet<Point> ret = new TreeSet<Point>(new PointComparator());
        ret.addAll(points.values());
        return ret;
    }
}

















